@@ -1,4 +1,4 @@
-/* error.c	error handling functions
+/* error.c --- Error handling functions.
  * Copyright (C) 2002, 2003, 2004  Simon Josefsson
  *
  * This file is part of Shishi.
@@ -85,7 +85,9 @@ struct shishi_error_msgs _shishi_error_messages[] = {
 
 /**
  * shishi_strerror:
- * @err: shishi error code
+ * @err: shishi error code.
+ *
+ * Convert return code to human readable string.
  *
  * Return value: Returns a pointer to a statically allocated string
  * containing a description of the error with the error value @err.
@@ -94,7 +96,7 @@ struct shishi_error_msgs _shishi_error_messages[] = {
 const char *
 shishi_strerror (int err)
 {
-  char *p = NULL;
+  const char *p = _("Unknown error");
   size_t i;
 
   for (i = 0; _shishi_error_messages[i].errorcode != -1; i++)
@@ -104,10 +106,6 @@ shishi_strerror (int err)
 	break;
       }
 
-  if (!p)
-    /* XXX mem leak */
-    asprintf (&p, _("Unknown shishi error: %d"), err);
-
   return p;
 
 }
