@@ -24,9 +24,6 @@
 /* Get _shishi_sendrecv_tls, etc. */
 #include "starttls.h"
 
-/* Get _shishi_resolv, etc. */
-#include "resolver.h"
-
 /* Get _shishi_realminfo, etc. */
 #include "diskio.h"
 
@@ -37,7 +34,7 @@ static int
 shishi_sendrecv_udp (Shishi * handle,
 		     struct sockaddr *addr,
 		     const char *indata, int inlen,
-		     char **outdata, size_t *outlen, size_t timeout)
+		     char **outdata, size_t * outlen, size_t timeout)
 {
   struct sockaddr lsa;
   struct sockaddr_in *lsa_inp = (struct sockaddr_in *) &lsa;
@@ -116,7 +113,7 @@ static int
 shishi_sendrecv_tcp (Shishi * handle,
 		     struct sockaddr *addr,
 		     const char *indata, int inlen,
-		     char **outdata, size_t *outlen, size_t timeout)
+		     char **outdata, size_t * outlen, size_t timeout)
 {
   char tmpbuf[BUFSIZ];		/* XXX can we do without it?
 				   MSG_PEEK|MSG_TRUNC doesn't work for udp.. */
@@ -286,13 +283,13 @@ shishi_kdc_sendrecv_static (Shishi * handle, char *realm,
 static int
 shishi_kdc_sendrecv_srv_1 (Shishi * handle, char *realm,
 			   const char *indata, size_t inlen,
-			   char **outdata, size_t * outlen, dnshost_t rrs)
+			   char **outdata, size_t * outlen, Shishi_dns rrs)
 {
   int rc;
 
   for (; rrs; rrs = rrs->next)
     {
-      dns_srv_t srv = (dns_srv_t) rrs->rr;
+      Shishi_dns_srv srv = rrs->rr;
       struct addrinfo hints;
       struct addrinfo *ai;
       char *port;
@@ -340,7 +337,7 @@ shishi_kdc_sendrecv_srv (Shishi * handle, char *realm,
 			 const char *indata, size_t inlen,
 			 char **outdata, size_t * outlen)
 {
-  dnshost_t rrs;
+  Shishi_dns rrs;
   char *tmp;
   int rc;
 
@@ -348,7 +345,7 @@ shishi_kdc_sendrecv_srv (Shishi * handle, char *realm,
     printf ("Finding SRV RRs for %s...\n", realm);
 
   asprintf (&tmp, "_kerberos._udp.%s", realm);
-  rrs = _shishi_resolv (tmp, T_SRV);
+  rrs = shishi_resolv (tmp, SHISHI_DNS_SRV);
   free (tmp);
 
   if (rrs)
@@ -360,7 +357,7 @@ shishi_kdc_sendrecv_srv (Shishi * handle, char *realm,
       rc = SHISHI_KDC_NOT_KNOWN_FOR_REALM;
     }
 
-  _shishi_resolv_free (rrs);
+  shishi_resolv_free (rrs);
 
   return rc;
 }
